<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// 0
'0_URL' => 'http://listes.rezo.net/mailman/listinfo/spip-dev',
'0_langue' => 'Catal&agrave; [ca]',
'0_liste' => ' spip-dev@rezo.net',
'0_mainteneur' => ' spip-dev@rezo.net',

// A
'access_interface_graphique' => 'Retorn a la interf&iacute;cie gr&agrave;fica completa',
'access_mode_texte' => 'Mostrar la interf&iacute;cie en mode text simplificada',
'admin_debug' => 'depuraci&oacute;',
'admin_modifier_article' => 'Modificar aquest article',
'admin_modifier_auteur' => 'Modificar aquest/a autor/a',
'admin_modifier_breve' => 'Modificar aquesta breu',
'admin_modifier_mot' => 'Modificar aquesta paraula clau',
'admin_modifier_rubrique' => 'Modificar aquesta secci&oacute;',
'admin_recalculer' => 'Recarregar aquesta p&agrave;gina',
'afficher_trad' => 'visualitzar les traduccions',
'alerte_maj_impossible' => '<b>Alerta&nbsp;!</b> L\'actualitzaci&oacute; de la base de dades SQL cap a la versi&oacute; @version@ &eacute;s impossible. Pot ser que tingueu un problema de drets de modificaci&oacute; de la base de dades. Si us plau, contacteu amb el vostre prove&iuml;dor d\'hostatge.',
'alerte_modif_info_concourante' => 'ATENCI&Oacute;: Aquesta informaci&oacute; s\'ha modificat per una altra banda. El valor actual &eacute;s:',
'analyse_xml' => 'An&agrave;lisi XML',
'annuler' => 'Anul&middot;lar',
'antispam_champ_vide' => 'Si us plau, deixeu aquest camp buit:',
'articles_recents' => 'Els articles m&eacute;s recents',
'avis_archive_incorrect' => 'el fitxer no &eacute;s pas un fitxer SPIP',
'avis_archive_invalide' => 'el fitxer no &eacute;s pas v&agrave;lid',
'avis_attention' => ' ATENCI&Oacute;&nbsp;!',
'avis_champ_incorrect_type_objet' => 'Nom de camp incorrecte @name@ per objecte del tipus @type@',
'avis_colonne_inexistante' => 'La columna @col@ no existeix pas',
'avis_echec_syndication_01' => 'La sindicaci&oacute; ha fallat : el backend indicat &eacute;s indescifrable o no proposa cap article.',
'avis_echec_syndication_02' => 'La sindicaci&oacute; ha fallat : impossible accedir al backend d\'aquest lloc.',
'avis_erreur' => 'Error: veure ac&iacute; baix',
'avis_erreur_connexion' => 'Error de connexi&oacute;',
'avis_erreur_cookie' => 'problema de galeta (cookie)',
'avis_erreur_fonction_contexte' => 'Error de programaci&oacute;. Aquesta funci&oacute; no ha de ser cridada en aquest context.',
'avis_erreur_mysql' => 'Error SQL',
'avis_erreur_sauvegarde' => ' Error al desar (@type@ @id_objet@) !',
'avis_erreur_visiteur' => 'Problema d\'acc&eacute;s a l\'espai privat',

// B
'barre_a_accent_grave' => 'Inserir una A maj&uacute;scula amb accent greu',
'barre_aide' => 'Utilitzi les dreceres tipogr&agrave;fiques per enriquir la seva compaginaci&oacute;',
'barre_e_accent_aigu' => 'Inserir una E maj&uacute;scula amb accent agut',
'barre_eo' => 'Inserir una E dins la O',
'barre_eo_maj' => 'Inserir una E dins l\'O maj&uacute;scula',
'barre_euro' => 'Inserir el simbol &euro;',
'barre_gras' => 'Posar en {{negreta}}',
'barre_guillemets' => 'Posar entre &laquo; cometes franceses &raquo; ',
'barre_guillemets_simples' => 'Posar entre "cometes"',
'barre_intertitre' => 'Transformar en {{{subt&iacute;tol}}}',
'barre_italic' => 'Posar en {it&agrave;lica}',
'barre_lien' => 'Transformar en [enlla&ccedil;->http://...]',
'barre_lien_input' => 'Indiqueu l\'adre&ccedil;a del vostre lloc (podeu utilitzar la forma http://www.elmeulloc/com o simplement indicar el num&eacute;ro d\'un article d\'aquest lloc.',
'barre_note' => 'Transformar en [[Nota a peu de p&agrave;gina]]',
'barre_paragraphe' => 'Crear un par&agrave;graf',
'barre_quote' => '<quote>Citar un missatge</quote>',
'bouton_ajouter_document' => 'Afegir un document',
'bouton_ajouter_image' => 'Afegir una imatge',
'bouton_ajouter_image_document' => 'Afegir una imatge o&nbsp;un&nbsp;document',
'bouton_changer' => 'Canviar',
'bouton_chercher' => 'Buscar',
'bouton_choisir' => 'Escollir',
'bouton_download' => 'Descarregar',
'bouton_enregistrer' => 'Enregistrar',
'bouton_radio_desactiver_messagerie_interne' => 'Desactivar la missatgeria interna',
'bouton_radio_envoi_annonces' => 'Enviar els anuncis editorials',
'bouton_radio_non_envoi_annonces' => 'No enviar anuncis',
'bouton_radio_non_envoi_liste_nouveautes' => 'No enviar la llista de novetats',
'bouton_recharger_page' => 'recarregar aquesta p&agrave;gina',
'bouton_telecharger' => 'Baixar',
'bouton_valider' => 'Validar',

// C
'cal_apresmidi' => 'tarda',
'cal_jour_entier' => 'dia sencer',
'cal_matin' => 'mat&iacute;',
'cal_par_jour' => 'calendari diari',
'cal_par_mois' => 'calendari mensual',
'cal_par_semaine' => 'calendari setmanal',
'choix_couleur_interface' => 'color',
'choix_interface' => 'elecci&oacute; de la interf&iacute;cie',
'colonne' => 'Columna',
'confirm_changer_statut' => 'Atenci&oacute;, heu demanat canviar l\'estat d\'aquest element. Voleu continuar? ',
'correcte' => 'correcte',

// D
'date_aujourdhui' => 'avui',
'date_avant_jc' => 'aC',
'date_dans' => 'en @delai@',
'date_de_mois_1' => '@j@ de gener',
'date_de_mois_10' => '@j@ d\'octubre',
'date_de_mois_11' => '@j@ de novembre',
'date_de_mois_12' => '@j@ de desembre',
'date_de_mois_2' => '@j@ de febrer',
'date_de_mois_3' => '@j@ de mar&ccedil;',
'date_de_mois_4' => '@j@ d\'abril',
'date_de_mois_5' => '@j@ de maig',
'date_de_mois_6' => '@j@ de juny',
'date_de_mois_7' => '@j@ de juliol',
'date_de_mois_8' => '@j@ d\'agost',
'date_de_mois_9' => '@j@ de setembre',
'date_demain' => 'dem&agrave;',
'date_fmt_heures_minutes' => '@h@h@m@min',
'date_fmt_jour_heure' => '@jour@ a les @heure@',
'date_fmt_jour_mois' => '@jourmois@',
'date_fmt_jour_mois_annee' => '@jourmois@ de @annee@',
'date_fmt_mois_annee' => '@nommois@ de @annee@',
'date_fmt_nomjour_date' => 'el @nomjour@ @date@',
'date_heures' => 'hores',
'date_hier' => 'ahir',
'date_il_y_a' => 'fa @delai@',
'date_jnum1' => '1',
'date_jnum10' => '10',
'date_jnum11' => '11',
'date_jnum12' => '12',
'date_jnum13' => '13',
'date_jnum14' => '14',
'date_jnum15' => '15',
'date_jnum16' => '16',
'date_jnum17' => '17',
'date_jnum18' => '18',
'date_jnum19' => '19',
'date_jnum2' => '2',
'date_jnum20' => '20',
'date_jnum21' => '21',
'date_jnum22' => '22',
'date_jnum23' => '23',
'date_jnum24' => '24',
'date_jnum25' => '25',
'date_jnum26' => '26',
'date_jnum27' => '27',
'date_jnum28' => '28',
'date_jnum29' => '29',
'date_jnum3' => '3',
'date_jnum30' => '30',
'date_jnum31' => '31',
'date_jnum4' => '4',
'date_jnum5' => '5',
'date_jnum6' => '6',
'date_jnum7' => '7',
'date_jnum8' => '8',
'date_jnum9' => '9',
'date_jour_1' => 'diumenge',
'date_jour_1_abbr' => 'dg.',
'date_jour_1_initiale' => 'dg',
'date_jour_2' => 'dilluns',
'date_jour_2_abbr' => 'dl.',
'date_jour_2_initiale' => 'dl',
'date_jour_3' => 'dimarts',
'date_jour_3_abbr' => 'dt.',
'date_jour_3_initiale' => 'dt',
'date_jour_4' => 'dimecres',
'date_jour_4_abbr' => 'dc.',
'date_jour_4_initiale' => 'dc',
'date_jour_5' => 'dijous',
'date_jour_5_abbr' => 'dj.',
'date_jour_5_initiale' => 'dj',
'date_jour_6' => 'divendres',
'date_jour_6_abbr' => 'dv.',
'date_jour_6_initiale' => 'dv',
'date_jour_7' => 'dissabte',
'date_jour_7_abbr' => 'ds.',
'date_jour_7_initiale' => 'ds',
'date_jours' => 'dies',
'date_minutes' => 'minuts',
'date_mois' => 'mes',
'date_mois_1' => 'gener',
'date_mois_10' => 'octubre',
'date_mois_11' => 'novembre',
'date_mois_12' => 'desembre',
'date_mois_2' => 'febrer',
'date_mois_3' => 'mar&ccedil;',
'date_mois_4' => 'abril',
'date_mois_5' => 'maig',
'date_mois_6' => 'juny',
'date_mois_7' => 'juliol',
'date_mois_8' => 'agost',
'date_mois_9' => 'setembre',
'date_saison_1' => 'hivern',
'date_saison_2' => 'primavera',
'date_saison_3' => 'estiu',
'date_saison_4' => 'tardor',
'date_secondes' => 'segons',
'date_semaines' => 'setmanes',
'date_un_mois' => 'mes',
'date_une_heure' => 'hora',
'date_une_minute' => 'minut',
'date_une_seconde' => 'segon',
'date_une_semaine' => 'setmana',
'dirs_commencer' => 'per comen&ccedil;ar realment la instal&middot;laci&oacute;',
'dirs_preliminaire' => 'Preliminar: <b>Regular els drets d\'acc&eacute;s</b>',
'dirs_probleme_droits' => 'Problema de drets d\'acc&eacute;s',
'dirs_repertoires_absents' => '<p><b>No s\'han trobat els seg&uuml;ents directoris: </b></p><ul>@bad_dirs@</ul>  <p>&Eacute;s probable que la causa sigui un problema d\'escriptura de les maj&uacute;scules o les min&uacute;scules.
  Verifiqueu que les min&uacute;scules i les maj&uacute;scules d\'aquests directoris coincideixin exactament amb el que es mostra m&eacute;s amunt; si aquest no &eacute;s el cas, canvieu el nom dels directoris amb l\'ajuda del vostre programa FTP per tal de corregir l\'error.</p>
  <p>Un cop feta aquesta manipulaci&oacute;, podreu ',
'dirs_repertoires_suivants' => '<p><b>Els seg&uuml;ents directoris no s&oacute;n accessibles a l\'escriptura:</b></p> <ul>@bad_dirs@</ul>
  <p>Per solucionar-ho, feu servir el vostre client FTP per tal de regular els drets d\'acc&eacute;s de cadascun d\'aquests directoris. El procediment s\'explica detalladament a la guia d\'instal&middot;laci&oacute;.</p>
  <p>Un cop feta aquesta manipulaci&oacute;, podreu ',
'double_occurrence' => 'Doble inst&agrave;ncia de @balise@ ',

// E
'en_cours' => 'en curs',
'entree_dimensions' => 'Dimensions:',
'entree_titre_document' => 'T&iacute;tol del document:',
'entree_titre_image' => 'T&iacute;tol de la imatge:',
'envoi_via_le_site' => 'Enviament per mitj&agrave; del lloc Web',
'erreur' => 'Error',
'erreur_balise_non_fermee' => '&uacute;ltima etiqueta sense tancar:',
'erreur_texte' => 'error(s)',
'etape' => 'Etapa',

// F
'fichier_introuvable' => 'Fitxer @fichier@ introbable',
'form_auteur_confirmation' => 'Confirmeu el vostre correu electr&ograve;nic',
'form_auteur_email_modifie' => 'El vostre correu electr&ograve;nic s\'ha modificat.',
'form_auteur_envoi_mail_confirmation' => 'Us acabem d\'enviar un correu electr&ograve;nic de confirmaci&oacute; a @email@. Per validar la vostra adre&ccedil;a de correu electr&ograve;nic, haureu de visitar l\'adre&ccedil;a Web esmentada en aquest correu.',
'form_auteur_mail_confirmation' => 'Bon dia,

Heu demanat canviar la vostra adre&ccedil;a electr&ograve;nica.
Per confirmar la nova adre&ccedil;a, nom&eacute;s heu de connectar-vos a l\'adre&ccedil;a que hi ha m&eacute;s avall (de no fer-ho aix&iacute;, la vostra petici&oacute; s\'ignorar&agrave;):

    @url@
',
'form_deja_inscrit' => 'Ja est&agrave;s inscrit/a.',
'form_email_non_valide' => 'La seva adre&ccedil;a electr&ograve;nica no ha estat validada.',
'form_forum_access_refuse' => 'No teniu acc&eacute;s a aquest lloc.',
'form_forum_bonjour' => 'Bon dia @nom@,',
'form_forum_email_deja_enregistre' => 'Aquesta adre&ccedil;a electr&ograve;nica ja ha estat enregistrada, podeu utilitzar la vostra contrasenya habitual. ',
'form_forum_identifiant_mail' => 'La identificaci&oacute; us ha estat enviada per correu electr&ograve;nic. ',
'form_forum_identifiants' => 'Identificadors personals',
'form_forum_indiquer_nom_email' => 'Indiqueu aqu&iacute; el vostre nom i la vostra adre&ccedil;a electr&ograve;nica. L\'identificador personal us ser&agrave; enviat, ben aviat, per correu electr&ograve;nic.',
'form_forum_login' => 'Usuari:',
'form_forum_message_auto' => '(aix&ograve; &eacute;s un missatge autom&agrave;tic)',
'form_forum_pass' => 'contrasenya:',
'form_forum_probleme_mail' => 'Problema d\'adre&ccedil;a electr&ograve;nica: l\'identificador no es pot enviar.',
'form_forum_voici1' => 'Aqu&iacute; teniu els identificadors per poder participar als f&ograve;rums del lloc Web "@nom_site_spip@" (@adresse_site@):',
'form_forum_voici2' => 'Aquests s&oacute;n els identificadors per poder proposar articles en aquest lloc
"@nom_site_spip@" (@adresse_login@):',
'form_indiquer_email' => 'Indiqueu la vostra adre&ccedil;a electr&ograve;nica.',
'form_indiquer_nom' => 'Indiqueu el vostre nom.',
'form_indiquer_nom_site' => 'Indiqueu el nom del vostre lloc.',
'form_pet_adresse_site' => 'L\'adre&ccedil;a del vostre lloc',
'form_pet_aucune_signature' => 'No hi ha cap signatura que correspongui a aquest codi...',
'form_pet_confirmation' => 'Confirmeu la vostra signatura:',
'form_pet_deja_enregistre' => 'Aquest lloc ja est&agrave; registrat.',
'form_pet_deja_signe' => 'Ja heu signat aquest text.',
'form_pet_envoi_mail_confirmation' => 'Us acabem d\'enviar un correu electr&ograve;nic de confirmaci&oacute; a @email@. Heu d\'anar a l\'adre&ccedil;a Web que s\'hi esmenta per validar la vostra signatura. ',
'form_pet_mail_confirmation' => 'Bon dia,

Heu sol&middot;licitat signar la petici&oacute;:
@titre@.

Heu facilitat les seg&uuml;ents informacions:
    Nom: @nom_email@
    Lloc: @nom_site@ - @url_site@
    @message@

IMPORTANT...
Per validar la vostra signatura, heu de connectar-vos a l\'adre&ccedil;a
indicada a continuaci&oacute; (en cas contrari, la sol&middot;licitud ser&agrave;
rebutjada) :

    @url@


Gr&agrave;cies per la participaci&oacute;
',
'form_pet_message_commentaire' => 'Un missatge, un commentari?',
'form_pet_nom_site2' => 'Nom del vostre lloc Web',
'form_pet_probleme_liens' => 'Vulgueu reprendre el vostre missatge suprimint-ne els enlla&ccedil;os.',
'form_pet_probleme_technique' => 'Problema t&egrave;cnic, les signatures estan temporalment suspeses.',
'form_pet_signature_pasprise' => 'La seva signatura no s\'ha tingut en compte.',
'form_pet_signature_validee' => 'La seva signatura ha estat validada. Gr&agrave;cies!',
'form_pet_site_deja_enregistre' => 'Aquest lloc est&agrave; ja enregistrat',
'form_pet_url_invalide' => 'L\'URL que heu indicat no &eacute;s v&agrave;lida.',
'form_pet_votre_email' => 'Correu electr&ograve;nic:',
'form_pet_votre_nom' => 'El vostre nom o pseud&ograve;nim',
'form_pet_votre_site' => 'Si teniu un lloc Web, podeu indicar-ho aqu&iacute; sota',
'form_prop_confirmer_envoi' => 'Confirmar l\'enviament',
'form_prop_description' => 'Descripci&oacute;/commentari',
'form_prop_enregistre' => 'La seva proposta ha estat registrada, apareixer&agrave; en l&iacute;nia despr&eacute;s de ser validada pels responsables d\'aquest lloc.',
'form_prop_envoyer' => 'Enviar un missatge',
'form_prop_indiquer_email' => 'Indiqueu una adre&ccedil;a electr&ograve;nica v&agrave;lida',
'form_prop_indiquer_nom_site' => 'Indiqueu el nom del lloc.',
'form_prop_indiquer_sujet' => 'Indiqueu un assumpte',
'form_prop_message_envoye' => 'Missatge enviat',
'form_prop_nom_site' => 'Nom del lloc',
'form_prop_non_enregistre' => 'La seva proposta no ha estat registrada.',
'form_prop_sujet' => 'Assumpte:',
'form_prop_url_site' => 'Adre&ccedil;a (URL) del lloc',
'forum_acces_refuse' => 'Ja no teniu acc&eacute;s a aquests f&ograve;rums.',
'forum_attention_dix_caracteres' => '<b>Atenci&oacute;!</b> el vostre missatge ha de tenir almenys deu car&agrave;cters.',
'forum_attention_trois_caracteres' => '<b>Atenci&oacute;!</b> el vostre t&iacute;tol ha de tenir almenys tres car&agrave;cters.',
'forum_attention_trop_caracteres' => '<b>Atenci&oacute;!</b> el vostre missatge &eacute;s massa llarg (@compte@ car&agrave;cters)&nbsp;: per a poder-vos enregistrar no pot sobrepassar els @max@ car&agrave;cters.',
'forum_avez_selectionne' => 'Heu seleccionat:',
'forum_cliquer_retour' => 'Premeu <a href=\'@retour_forum@\'>ici</a> per continuar.',
'forum_forum' => 'f&ograve;rum',
'forum_info_modere' => 'Aquest f&ograve;rum &eacute;s moderat a priori: la seva contribuci&oacute; no es mostrar&agrave; fins que no hagi estat validada per l\'administrador del lloc. ',
'forum_lien_hyper' => '<b>Enlla&ccedil; hipertext</b> (opcional)',
'forum_message_definitif' => 'Missatge definitiu: enviar al lloc',
'forum_message_trop_long' => 'El vostre missatge &eacute;s massa llarg. La mida m&agrave;xima s&oacute;n 20000 car&agrave;cters.',
'forum_ne_repondez_pas' => 'No respongueu a aquest correu electr&ograve;nic, feu-ho al f&ograve;rum que trobareu a la seg&uuml;ent adre&ccedil;a: ',
'forum_non_inscrit' => 'No esteu inscrit o b&eacute; l\'adre&ccedil;a o la contrasenya s&oacute;n err&ograve;nies. ',
'forum_page_url' => '(Si el vostre missatge fa refer&egrave;ncia a un article publicat a la Web, o a una p&agrave;gina que cont&eacute; m&eacute;s informacions, podeu indicar a continuaci&oacute; el t&iacute;tol de la p&agrave;gina i la seva adre&ccedil;a URL.)',
'forum_par_auteur' => 'per @auteur@',
'forum_poste_par' => 'Missatge enviat@parauteur@ a continuaci&oacute; de l\'article &laquo; @titre@ &raquo;.',
'forum_probleme_database' => 'Problema de la base de dades, el vostre missatge no s\'ha registrat.',
'forum_qui_etes_vous' => '<b>Qui s&oacute;u?</b> (opcional)',
'forum_texte' => 'Text del missatge:',
'forum_titre' => 'Titol:',
'forum_titre_erreur' => 'Error...',
'forum_url' => 'URL:',
'forum_valider' => 'Validar l\'elecci&oacute;',
'forum_voir_avant' => 'Veure el missatge abans d\'enviar-lo',
'forum_votre_email' => 'La seva adre&ccedil;a electr&ograve;nica:',
'forum_votre_nom' => 'El vostre nom (o pseud&ograve;nim):',
'forum_vous_enregistrer' => 'Per participar al f&ograve;rum, us heu de registrar pr&egrave;viament.
Si ja n\'esteu, escriviu a continuaci&oacute; l\'identifcador que us ha estat proporcionat. Si encara no ho heu fet, heu d\'',
'forum_vous_inscrire' => 'inscriure\'s.',

// I
'ical_texte_rss_articles' => 'El fitxer &laquo;backend&raquo; dels articles d\'aquest lloc es troba a l\'adre&ccedil;a:',
'ical_texte_rss_articles2' => 'Podeu igualment obtenir fitxers &laquo;backend&raquo; pels articles de cada secci&oacute; d\'aquest lloc:',
'ical_texte_rss_breves' => 'Existeix tamb&eacute; un fitxer que cont&eacute; les breus del lloc. Especificant el n&uacute;mero de secci&oacute;, es poden obtenir &uacute;nicament les breus d\'aquesta.',
'icone_a_suivre' => 'Novetats',
'icone_admin_site' => 'Administraci&oacute; del lloc',
'icone_agenda' => 'Agenda',
'icone_aide_ligne' => 'Ajuda',
'icone_articles' => 'Articles',
'icone_auteurs' => 'Autors/es',
'icone_breves' => 'Breus',
'icone_brouteur' => 'Navegaci&oacute; r&agrave;pida',
'icone_configuration_site' => 'Configuraci&oacute;',
'icone_configurer_site' => 'Configurar el vostre lloc',
'icone_creer_nouvel_auteur' => 'Crear un nou autor o autora',
'icone_creer_rubrique' => 'Crear una secci&oacute;',
'icone_creer_sous_rubrique' => 'Crear una subsecci&oacute;',
'icone_deconnecter' => 'Desconnectar-se',
'icone_discussions' => 'Discussions',
'icone_doc_rubrique' => 'Documents de les seccions',
'icone_ecrire_article' => 'Escriure un nou article',
'icone_edition_site' => 'Edici&oacute;',
'icone_forum_administrateur' => 'F&ograve;rum dels administradors/administradores',
'icone_forum_suivi' => 'Seguiment dels f&ograve;rums',
'icone_gestion_langues' => 'Gesti&oacute; de les lleng&uuml;es',
'icone_informations_personnelles' => 'Informacions personals',
'icone_interface_complet' => 'interf&iacute;cie completa',
'icone_interface_simple' => 'Interf&iacute;cie simple',
'icone_maintenance_site' => 'Manteniment del lloc',
'icone_messagerie_personnelle' => 'Missatgeria personal',
'icone_mots_cles' => 'Paraules clau',
'icone_nouvelle_breve' => 'Escriure una nova breu',
'icone_repartition_actuelle' => 'Mostrar la distribuci&oacute; actual',
'icone_repartition_debut' => 'Mostrar la distribuci&oacute; des del comen&ccedil;ament',
'icone_repartition_visites' => 'Repartiment de les visites',
'icone_rubriques' => 'Seccions',
'icone_sauver_site' => 'C&ograve;pia de seguretat del lloc',
'icone_site_entier' => 'Tot el lloc',
'icone_sites_references' => 'Llocs referenciats',
'icone_statistiques' => 'Estad&iacute;stiques del lloc',
'icone_statistiques_visites' => 'Estad&iacute;stiques',
'icone_suivi_activite' => 'Seguir la vida del lloc',
'icone_suivi_actualite' => 'Evoluci&oacute; del lloc',
'icone_suivi_forums' => 'Seguir/gestionar els f&ograve;rums',
'icone_suivi_pettions' => 'Seguir/gestionar les peticions',
'icone_suivi_revisions' => 'Modificacions dels articles ',
'icone_supprimer_document' => 'Suprimir aquest document',
'icone_supprimer_image' => 'Suprimir aquesta imatge',
'icone_supprimer_message' => 'Suprimir aquest missatge',
'icone_tous_articles' => 'Tots els seus articles',
'icone_tous_auteur' => 'Tots els autors i autores',
'icone_valider_message' => 'Validar aquest missatge',
'icone_visiter_site' => 'Visitar',
'icone_voir_en_ligne' => 'Visualitzar en l&iacute;nia',
'image_tourner_180' => 'Girar 180&deg;',
'image_tourner_droite' => 'Girar 90&deg; cap a la dreta',
'image_tourner_gauche' => 'Girar 90&deg; cap a l\'esquerre',
'img_indisponible' => 'imatge no disponible',
'impossible' => 'impossible',
'info_a_suivre' => 'NOVETATS&raquo;',
'info_a_valider' => '[per validar]',
'info_acces_interdit' => 'Acc&eacute;s prohibit',
'info_acces_refuse' => 'Acc&egrave;s refusat',
'info_action' => 'Acci&oacute;: @action@',
'info_administrer_rubriques' => 'Podeu administrat aquesta secci&oacute; i les seves subseccions',
'info_adresse_non_indiquee' => 'No heu indicat cap adre&ccedil;a per provar!',
'info_aide' => 'AJUDA:',
'info_ajouter_mot' => 'Afegir aquesta paraula',
'info_annonce' => 'ANUNCI',
'info_annonces_generales' => 'Avisos generals:',
'info_article_propose' => 'Article proposat',
'info_article_publie' => 'Article publicat',
'info_article_redaction' => 'Article en curs de redacci&oacute;',
'info_article_refuse' => 'Article rebutjat',
'info_article_supprime' => 'Article suprimit',
'info_articles' => 'Articles',
'info_articles_a_valider' => 'Articles per validar',
'info_articles_nb' => '@nb@ articles',
'info_articles_proposes' => 'Articles proposats',
'info_articles_un' => '1 article',
'info_auteurs_nombre' => 'autor(s)/es:',
'info_authentification_ftp' => 'Autenticaci&oacute; (per FTP).',
'info_bloquer_lien' => 'blocar aquest enlla&ccedil;',
'info_breves_02' => 'Breus',
'info_breves_2' => 'breus',
'info_breves_nb' => '@nb@ breus',
'info_breves_un' => '1 breu',
'info_breves_valider' => 'Breus per validar',
'info_connexion_refusee' => 'Connexi&oacute; denegada',
'info_contact_developpeur' => 'Contacteu amb un desenvolupador.',
'info_contenance' => 'Aquest lloc cont&eacute;:',
'info_contribution' => 'contribucions del f&ograve;rum',
'info_copyright' => '@spip@ &eacute;s programari lliure distribu&iuml;t @lien_gpl@.',
'info_copyright_doc' => 'Per a m&eacute;s informaci&oacute;, veure el lloc <a href="@spipnet@">http://www.spip.net/ca</a>.',
'info_copyright_gpl' => 'sota llic&egrave;ncia GPL',
'info_cours_edition' => 'Els vostres articles en proc&eacute;s de redacci&oacute;',
'info_creer_repertoire' => 'Creeu un fitxer o un directori anomenat:',
'info_creer_repertoire_2' => 'a l\'interior del subdirectori <b>@repertoire@</b>, despr&eacute;s:',
'info_creer_vignette' => 'creaci&oacute; autom&agrave;tica de la miniatura',
'info_deplier' => 'Desplegar',
'info_descriptif_nombre' => 'descripci&oacute;(ns):',
'info_description' => 'Descripci&oacute;:',
'info_description_2' => 'Descripci&oacute;:',
'info_dimension' => 'Mida:',
'info_document' => 'Document',
'info_document_indisponible' => 'Aquest document no est&agrave; disponible',
'info_documents' => 'Documents',
'info_documents_nb' => '@nb@ documents',
'info_documents_un' => '1 document',
'info_echange_message' => 'SPIP permet l\'intercanvi de missatges i la creaci&oacute; de f&ograve;rums de discussi&oacute;
  privats entre els participants d\'un lloc. Podeu habilitar o
  inhabilitar aquesta funcionalitat.',
'info_ecire_message_prive' => 'Escriure un missatge privat',
'info_email_invalide' => 'L\'adre&ccedil;a electr&ograve;nica no &eacute;s v&agrave;lida.',
'info_en_cours_validation' => 'Articles en proc&eacute;s de redacci&oacute;',
'info_en_ligne' => 'Actualment en l&iacute;nia:',
'info_envoyer_message_prive' => 'Enviar un missatge privat a aquest/a autor/a',
'info_erreur_requete' => 'Error en la petici&oacute;:',
'info_erreur_squelette2' => 'No hi ha cap esquelet <b>@fichier@</b> que estigui disponible...',
'info_erreur_systeme' => 'Error del sistema (errno @errsys@)',
'info_erreur_systeme2' => '&Eacute;s probable que el disc dur estigui ple, o la base de dades feta malb&eacute;. <br />
 <font color=\'red\'>Proveu de <a href=\'@script@\'>reparar la base</a>,
 o contacteu amb el vostre hostatjador.</font>',
'info_fini' => 'S\'ha acabat! ',
'info_format_image' => 'Formats d\'imatges que es poden fer servir per crear vinyetes: @gd_formats@.',
'info_format_non_defini' => ' format no definit',
'info_grand_ecran' => 'Pantalla gran',
'info_image_aide' => 'AJUDA',
'info_image_process_titre' => 'M&egrave;tode de fabricaci&oacute; de vignettes',
'info_impossible_lire_page' => '<b>Error!</b> Impossible llegir la p&agrave;gina <tt><html>@test_proxy@</html></tt> per mitj&agrave; del proxy',
'info_inclusion_directe' => 'Inclusi&oacute; directa:',
'info_inclusion_vignette' => 'Inclusi&oacute; de la icona:',
'info_installation_systeme_publication' => 'Instal&middot;laci&oacute; del sistema de publicaci&oacute;...',
'info_installer_documents' => 'Podeu instal&middot;lar autom&agrave;ticament tots els documents que hi ha dins la carpeta @upload@.',
'info_installer_ftp' => 'En tan que administrador, podeu instal&middot;lar (per FTP) els fitxers a la carpeta @upload@ per a continuaci&oacute; seleccionar-los directament aqu&iacute;.',
'info_installer_images' => 'Podeu instal&middot;lar imatges amb els formats JPEG, GIF i PNG.',
'info_installer_images_dossier' => 'Instal&middot;lar imatges a la carpeta @upload@ per poder-les seleccionar aqu&iacute;.',
'info_installer_tous_documents' => 'Instal&middot;lar tots els documents',
'info_interface_complete' => 'interf&iacute;cie completa',
'info_interface_simple' => 'Interf&iacute;cie simple',
'info_joindre_document_article' => 'Podeu adjuntar a aquest article documents del tipus ',
'info_joindre_document_rubrique' => 'Podeu adjuntar en aquesta secci&oacute; documents del tipus ',
'info_joindre_documents_article' => 'Poden adjuntar al vostre article documents del tipus:',
'info_l_article' => 'l\'article',
'info_la_breve' => 'la breu',
'info_la_rubrique' => 'la secci&oacute;',
'info_langue_principale' => 'Idioma principal del lloc',
'info_largeur_vignette' => '@largeur_vignette@ &times; @hauteur_vignette@ pixels',
'info_les_auteurs_1' => 'per @les_auteurs@',
'info_logo_format_interdit' => 'Nom&eacute;s els logotips amb formats @formats@ estan autoritzats.',
'info_logo_max_poids' => 'Els logotips han de fer obligat&ograve;riament menys de @maxi@ (aquest fitxer fa @actuel@).',
'info_logo_max_taille' => 'Els logotips han de fer obligat&ograve;riament menys de @maxi@ (aquest fitxer fa @actuel@).',
'info_mail_fournisseur' => 'elteu@proveidor.com',
'info_message_2' => 'MISSATGE',
'info_message_supprime' => 'MISSATGE SUPRIMIT',
'info_messages_nb' => '@nb@ missatges',
'info_messages_un' => '1 missatge',
'info_mise_en_ligne' => 'Data de publicaci&oacute;:',
'info_modification_parametres_securite' => 'modificacions dels par&agrave;metres de seguretat',
'info_mois_courant' => 'Durant aquest mes:',
'info_mot_cle_ajoute' => 'La paraula clau seg&uuml;ent ha estat afegida',
'info_multi_herit' => 'Idioma per defecte',
'info_multi_langues_soulignees' => 'Les <u>lleng&uuml;es subratllades</u> es beneficien d\'una traducci&oacute; de tots els textos de la interf&iacute;cie. Si seleccioneu aquestes lleng&uuml;es, molts elements del lloc p&uacute;blic (dates, formularis) es traduiran autom&agrave;ticament. En les lleng&uuml;es no subratllades, aquests elements es mostraran en la llengua principal del lloc.',
'info_multilinguisme' => 'Multiling&uuml;isme',
'info_nom_non_utilisateurs_connectes' => 'El vostre nom no apareix a la llista d\'usuaris/&agrave;ries connectats/des.',
'info_nom_utilisateurs_connectes' => 'El vostre nom apareix a la llista dels usuaris connectats.',
'info_nombre_en_ligne' => 'Actualment en l&iacute;nia:',
'info_non_resultat' => 'Cap resultat per "@cherche_mot@"',
'info_non_utilisation_messagerie' => 'No feu servir la missatgeria interna d\'aquest lloc.',
'info_nouveau_message' => 'TENIU UN NOU MISSATGE',
'info_nouveaux_messages' => 'TENIU @total_messages@ NOUS MISSATGES',
'info_numero_abbreviation' => 'N&deg;&nbsp;',
'info_obligatoire' => 'Aquesta informaci&oacute; &eacute;s obligat&ograve;ria',
'info_panne_site_syndique' => 'Lloc sindicat en pana',
'info_pense_bete' => 'RECORDATORI',
'info_petit_ecran' => 'Pantalla petita',
'info_petition_close' => 'Petici&oacute; tancada',
'info_pixels' => 'pixels',
'info_plusieurs_mots_trouves' => 'S\'ha trobat diverses paraules clau per "@cherche_mot@":',
'info_popularite_5' => 'popularitat:',
'info_portfolio' => 'Carpeta',
'info_portfolio_automatique' => 'Carpeta autom&agrave;tica:',
'info_premier_resultat' => '[@debut_limit@ primers resultats sobre @total@]',
'info_premier_resultat_sur' => '[@debut_limit@ primers resultats sobre @total@]',
'info_probleme_grave' => 'problema de',
'info_propose_1' => '[@nom_site_spip@] Proposa: @titre@',
'info_propose_2' => 'Article proposat
----------------',
'info_propose_3' => 'L\'article "@titre@" est&agrave; proposat per a ser publicat.',
'info_propose_4' => 'Esteu convidats a consultar-lo i a donar la vostra opini&oacute;',
'info_propose_5' => 'al f&ograve;rum que hi enlla&ccedil;a. El trobareu disponible a l\'adre&ccedil;a:',
'info_publie_01' => 'L\'article "@titre@" ha estat validat per @connect_nom@.',
'info_publie_1' => '[@nom_site_spip@] PUBLICAT: @titre@',
'info_publie_2' => 'Article publicat
----------------',
'info_rechercher' => 'Cercar',
'info_rechercher_02' => 'Cercar:',
'info_remplacer_vignette' => 'Substituir la icona per defecte per un logotip personalitzat:',
'info_retablir_lien' => 'restaurar aquest enlla&ccedil;',
'info_retirer_mot' => 'suprimir aquesta paraula',
'info_retirer_mots' => 'suprimir totes les paraules',
'info_rubriques_nb' => '@nb@ seccions',
'info_rubriques_un' => '1 secci&oacute;',
'info_sans_titre_2' => 'sense t&iacute;tol',
'info_selectionner_fichier' => 'Podeu seleccionar un fitxer de la carpeta @upload@',
'info_selectionner_fichier_2' => 'Seleccionar un fitxer:',
'info_signature_supprimee' => 'Signatura eliminada',
'info_signature_supprimee_erreur' => 'Error: el codi de supressi&oacute; no correspon a cap signatura',
'info_site_attente' => 'Lloc Web pendent de validaci&oacute;',
'info_site_reference' => 'Lloc referenciat en l&iacute;nia',
'info_site_refuse' => 'Lloc Web rebutjat',
'info_sites_nb' => '@nb@ llocs',
'info_sites_referencer' => 'Referenciar un lloc',
'info_sites_un' => '1 lloc',
'info_supprimer_vignette' => 'suprimir la icona',
'info_symbole_bleu' => 'El s&iacute;mbol <b>blau</b> indica un <b>recordatori</b>: &eacute;s a dir un missatge per a &uacute;s personal.',
'info_symbole_jaune' => 'El s&iacute;mbol <b>groc</b> indica un <b>av&iacute;s a tots els redactors</b>&nbsp;: modificable per tots els administradors i visible per tots els redactors.',
'info_symbole_vert' => 'El s&iacute;mbol <b>vert</b> indica els <b>missatges intercanviats amb altres usuaris</b> del lloc Web.',
'info_syndication' => 'sindicaci&oacute;:',
'info_syndication_articles' => 'article(s)',
'info_telecharger' => 'Carregar des del vostre ordinador:',
'info_telecharger_nouveau_logo' => 'Carregar un nou logotip:',
'info_telecharger_ordinateur' => 'Carregar des del vostre ordinador:',
'info_tous_resultats_enregistres' => '[tots els resultats s&oacute;n registrats]',
'info_tout_afficher' => 'Mostrar-ho tot',
'info_travaux_texte' => 'Aquest lloc encara no est&aacute; configurat. Torneu m&eacute;s endavant...',
'info_travaux_titre' => 'Lloc en construcci&oacute;',
'info_trop_resultat' => 'Massa resultats per "@cherche_mot@"; si voleu afinar la cerca.',
'info_utilisation_messagerie_interne' => 'Utilitzeu la missatgeria interna d\'aquest lloc.',
'info_valider_lien' => 'validar aquest enlla&ccedil;',
'info_verifier_image' => ', voleu verificar que les vostres imatges han estat transferides correctament.',
'info_vignette_defaut' => 'Icona per defecte',
'info_vignette_personnalisee' => 'Icona personalitzada',
'info_visite' => 'visita:',
'info_visites' => 'visites:',
'info_vos_rendez_vous' => 'Les vostres cites',
'info_zoom' => 'zoom',
'infos_vos_pense_bete' => 'Els vostres recordatoris',
'item_breve_proposee' => 'Breu proposada',

// L
'lien_afficher_icones_seuls' => 'Mostrar nom&eacute;s les icones',
'lien_afficher_texte_icones' => 'Mostrar les icones i el text',
'lien_afficher_texte_seul' => 'Mostrar nom&eacute;s el text',
'lien_liberer' => 'alliberar',
'lien_liberer_tous' => 'alliberar aquests articles',
'lien_nouvea_pense_bete' => 'NOU RECORDATORI',
'lien_nouveau_message' => 'NOU MISSATGE',
'lien_nouvelle_annonce' => 'NOU ANUNCI',
'lien_petitions' => 'PETICI&Oacute;',
'lien_popularite' => 'popularitat: @popularite@%',
'lien_racine_site' => 'ARREL DEL LLOC',
'lien_reessayer' => 'Reintentar',
'lien_repondre_message' => 'Respondre a aquest missatge',
'lien_supprimer' => 'suprimir',
'lien_tout_afficher' => 'Mostrar-ho tot',
'lien_visite_site' => 'visitar aquest lloc',
'lien_visites' => '@visites@&nbsp;visites',
'lien_voir_auteur' => 'Veure aquest autor',
'ligne' => 'L&iacute;nia',
'login' => 'Connexi&oacute;',
'login_acces_prive' => 'acc&eacute;s a l\'espai privat',
'login_autre_identifiant' => 'connectar-se amb un altre nom d\'usuari/&agrave;ria',
'login_cookie_accepte' => 'Configura el teu navegador perqu&egrave; les accepti (al menys per aquest lloc).',
'login_cookie_oblige' => 'Per identificar-vos d\'una manera segura en aquest lloc, heu d\'acceptar les galetes.',
'login_deconnexion_ok' => 'Desconnexi&oacute; efectuada.',
'login_erreur_pass' => 'Error de contrasenya.',
'login_espace_prive' => 'espai privat',
'login_identifiant_inconnu' => 'L\'usuari &laquo; @login@ &raquo; &eacute;s desconegut',
'login_login' => 'Login:',
'login_login2' => 'Login (identificador de connexi&oacute; al lloc):',
'login_login_pass_incorrect' => '(Login ou contrasenya incorretecte.)',
'login_motpasseoublie' => 'contrasenya oblidada?',
'login_non_securise' => 'Atenci&oacute;, aquest formulari no &eacute;s segur. Si no voleu que la vostra contrasenya pugui ser interceptada a la xarxa, activeu Javascript al vostre navegador i ',
'login_nouvelle_tentative' => 'Nou intent',
'login_par_ici' => 'Esteu registrats... per aqu&iacute;...',
'login_pass2' => 'Contrasenya:',
'login_preferez_refuser' => '<b>Si preferiu refusar les galetes</b>, un altre m&egrave;tode de connexi&oacute; (menys segur) &eacute;s a la vostra disposici&oacute; :',
'login_recharger' => 'actualitzar aquesta p&agrave;gina',
'login_rester_identifie' => 'continuar identificat alguns dies',
'login_retour_public' => 'Tornar al lloc p&uacute;blic',
'login_retour_site' => 'Tornar al lloc p&uacute;blic',
'login_retoursitepublic' => 'tornar al lloc p&uacute;blic',
'login_sans_cookiie' => 'Identificaci&oacute; sense galeta',
'login_securise' => 'Inici de sessi&oacute; segur',
'login_sinscrire' => 'inscriure\'s',
'login_test_navigateur' => 'prova de navegador/tornar a connectar',
'login_verifiez_navigateur' => '(Verifiqueu no obstant que el vostre navegador no ha memoritzat la contrasenya...)',

// M
'masquer_colonne' => 'Ocultar aquesta columna',
'masquer_trad' => 'amagar les traduccions',
'module_fichiers_langues' => 'Fitxers de llengua',

// N
'navigateur_pas_redirige' => 'Si el vostre navegador no &eacute;s redirigit, cliqueu aqu&iacute; per continuar.',
'numero' => 'N&uacute;mero',

// O
'occurence' => 'Inst&agrave;ncia',
'onglet_affacer_base' => 'Suprimir la base de dades',
'onglet_auteur' => 'L\'autor/a',
'onglet_contenu_site' => 'Contingut del lloc',
'onglet_evolution_visite_mod' => 'Evoluci&oacute;',
'onglet_fonctions_avances' => 'Funcions avan&ccedil;ades',
'onglet_informations_personnelles' => 'Informacions personals',
'onglet_interactivite' => 'Interactivitat',
'onglet_messagerie' => 'Missatgeria',
'onglet_messages_internes' => 'Missatges interns',
'onglet_messages_publics' => 'Missatges p&uacute;blics',
'onglet_messages_vide' => 'Missatges sense text',
'onglet_origine_visites' => 'Origen de les visites',
'onglet_repartition_debut' => 'des del comen&ccedil;ament',
'onglet_repartition_lang' => 'Repartiment per lleng&uuml;es',
'onglet_repartition_rubrique' => 'Distribuci&oacute; per seccions',
'onglet_save_restaur_base' => 'C&ograve;pia de seguretat/restaurar base de dades',
'onglet_vider_cache' => 'Buidar la mem&ograve;ria cau',

// P
'pass_choix_pass' => 'Escolliu la vostra nova contrasenya:',
'pass_erreur' => 'Error',
'pass_erreur_acces_refuse' => '<b>Error:</b> ja no teniu acc&eacute;s en aquest lloc.',
'pass_erreur_code_inconnu' => '<b>Error:</b> aquest codi no correspon a cap dels visitants que tenen acc&eacute;s a aquest lloc.',
'pass_erreur_non_enregistre' => '<b>Error:</b> l\'adre&ccedil;a <tt>@email_oubli@</tt> no est&agrave; registrada en aquest lloc.',
'pass_erreur_non_valide' => '<b>Error:</b> aquest correu electr&ograve;nic <tt>@email_oubli@</tt> no &eacute;s v&agrave;lid!',
'pass_erreur_probleme_technique' => '<b>Error:</b> per culpa d\'un problema t&egrave;cnic, el correu electr&ograve;nic no s\'ha pogut enviar.',
'pass_espace_prive_bla' => 'L\'espai privat d\'aquest lloc est&agrave; obert als visitants, un cop s\'han inscrit. Una vegada registrats, podeu consultar els articles en proc&eacute;s de redacci&oacute;, proposar articles i participar en tots els f&ograve;rums. ',
'pass_forum_bla' => 'Heu demanat d\'intervenir en un f&ograve;rum reservat als visitants registrats.',
'pass_indiquez_cidessous' => 'Indiqueu a sota l\'adre&ccedil;a electr&ograve;nica amb la que us heu registrat anteriorment. Rebreu un correu electr&ograve;nic indicant-vos els passos a seguir per recuperar el vostre acc&eacute;s. ',
'pass_mail_passcookie' => '(aquest &eacute;s un missatge autom&agrave;tic)
Per recuperar el vostre acc&eacute;s al lloc
@nom_site_spip@ (@adresse_site@)

Aneu a l\'adre&ccedil;a seg&uuml;ent:

    @sendcookie@

Llavors podreu entrar una nova contrasenya
i tornar-vos a connectar al lloc.

',
'pass_mot_oublie' => 'Contrasenya oblidada',
'pass_nouveau_enregistre' => 'La vostra nova contrasenya ha estat registrada.',
'pass_nouveau_pass' => 'Nova contrasenya',
'pass_ok' => 'D\'acord',
'pass_oubli_mot' => 'Oblit de la contrasenya',
'pass_quitter_fenetre' => 'Tancar aquesta finestra',
'pass_rappel_login' => 'Recordatori: la vostra identificaci&oacute; (usuari) &eacute;s " @login@".',
'pass_recevoir_mail' => 'Voleu rebre un correu electr&ograve;nic indicant com recuperar l\'acc&eacute;s al lloc.',
'pass_retour_public' => 'Tornar al lloc p&uacute;blic',
'pass_rien_a_faire_ici' => 'Res a fer ac&iacute;.',
'pass_vousinscrire' => 'Incriure\'s a aquesta web',
'precedent' => 'anterior',
'previsualisation' => 'Previsualitzaci&oacute;',
'previsualiser' => 'Previsualitzar',

// R
'retour' => 'Retorn',

// S
'spip_conforme_dtd' => 'SPIP considera aquest document conforme al seu DOCTYPE :',
'squelette' => 'esquelet',
'squelette_inclus_ligne' => 'esquelet incl&ograve;s, l&iacute;nia',
'squelette_ligne' => 'esquelet, l&iacute;nia',
'stats_visites_et_popularite' => '@visites@ visites; popularitat: @popularite@',
'suivant' => 'seg&uuml;ent',

// T
'taille_ko' => '@taille@&nbsp;kB',
'taille_mo' => '@taille@&nbsp;MB',
'taille_octets' => '@taille@&nbsp;bytes',
'texte_actualite_site_1' => 'Quan estareu familiaritzats amb la interf&iacute;cie, podreu clicar a &laquo;',
'texte_actualite_site_2' => 'interf&iacute;cie completa',
'texte_actualite_site_3' => '" per obrir m&eacute;s possibilitats.',
'texte_creation_automatique_vignette' => 'La creaci&oacute; autom&agrave;tica d\'icones de previsualitzaci&oacute; est&agrave; activada amb els formats @gd_formats@, estaran acompanyades d\'una icona com a  m&agrave;xim de @taille_preview@ pixels.',
'texte_documents_associes' => 'Els documents seg&uuml;ents estan associats a l\'article, per&ograve; no han estat directament inclosos. Segons la compaginaci&oacute; del lloc p&uacute;blic, es podran mostrar com a documents adjunts.',
'texte_erreur_mise_niveau_base' => 'Error de la base de dades durant la seva actualitzaci&oacute;.
 La imatge <b>@fichier@</b> no ha passat (article @id_article@).
  Anoteu aquesta refer&egrave;ncia, proveu altre cop
 l\'actualitzaci&oacute; i, finalment, verifiqueu que les imatges
 apareixen sempre als articles.',
'texte_erreur_visiteur' => 'Heu intentat accedir a l\'espai privat amb un login que no li permet.',
'texte_inc_auth_1' => 'Us heu identificat amb el nom d\'usuari <b>@auth_login@</b>, per&ograve; aquest no existeix/ja no existeix a la base de dades.
  Proveu de ',
'texte_inc_auth_2' => 'reconnectar',
'texte_inc_auth_3' => ', despr&eacute;s de tancar i tornar a arrencar el vostre ordinador.',
'texte_inc_config' => 'Les modificacions efectuades en aquestes p&agrave;gines influeixen notablement en el
 funcionament del vostre lloc Web. Us recomanem no tocar res fins que no estigueu familiaritzats amb el funcionament del sistema SPIP. <br /><br /><b> En general
,  es molt aconsellable
 deixar la c&agrave;rrega d\'aquestes p&agrave;gines al webmestre principal del vostre lloc Web.</b>',
'texte_inc_meta_1' => 'El sistema ha trobat un error durant l\'escritura del fitxer <code>@fichier@</code>.Si us plau, ja que sou l\'administrador/a del lloc web,',
'texte_inc_meta_2' => 'verifiqueu els drets d\'escriptura',
'texte_inc_meta_3' => 'del directori <code>@repertoire@</code>.',
'texte_statut_en_cours_redaction' => 'en curs de redacci&oacute;',
'texte_statut_poubelle' => 'a la paperera',
'texte_statut_propose_evaluation' => 'proposat per a l\'avaluaci&oacute;',
'texte_statut_publie' => 'publicat en l&iacute;nia',
'texte_statut_refuse' => 'refusat',
'titre_ajouter_mot_cle' => 'AFEGIR UN MOT CLAU:',
'titre_breve_proposee' => 'Breu proposat',
'titre_breve_publiee' => 'Breu publicada',
'titre_breve_refusee' => 'Breu refusat',
'titre_cadre_raccourcis' => 'DRECERES',
'titre_changer_couleur_interface' => 'Canviar el color de l\'interficie',
'titre_forum' => 'F&ograve;rum',
'titre_image_admin_article' => 'Vost&eacute; pot administrar aquest article',
'titre_image_administrateur' => 'Administrador/a',
'titre_image_aide' => 'De l\'ajuda sobre aquest element',
'titre_image_auteur_supprime' => 'Autor/a suprimit/da',
'titre_image_redacteur' => 'Redactor/a sense acc&eacute;s',
'titre_image_redacteur_02' => 'Redactor/a',
'titre_image_visiteur' => 'Visitant',
'titre_joindre_document' => 'INTRODUIR UN DOCUMENT',
'titre_liens_entrants' => 'Enlla&ccedil;os entrants',
'titre_mots_cles' => 'PARAULES CLAU',
'titre_probleme_technique' => 'Atenci&oacute;: un problema t&egrave;cnic (servidor SQL) impedeix l\'acc&eacute;s a aquesta part de la Web. Gr&agrave;cies per la vostra comprensi&oacute;.',
'titre_publier_document' => 'PUBLICAR UN DOCUMENT DINS D\'AQUESTA SECCI&Oacute;',
'titre_signatures_attente' => 'Signatures esperant ser validades',
'titre_signatures_confirmees' => 'Signatures confirmades',
'titre_statistiques' => 'Estadistiques de la p&agrave;gina',
'titre_titre_document' => 'T&iacute;tol del document:',
'todo' => 'pr&ograve;ximament  ',
'trad_reference' => '(article de refer&egrave;ncia)',

// Z
'zbug_balise_b_aval' => '&nbsp;: l\'etiqueta B ha d\'anar abans',
'zbug_balise_inexistante' => 'etiqueta @balise@ mal declarada per a @from@ ',
'zbug_balise_sans_argument' => 'Argument que falta a l\'etiqueta @balise@',
'zbug_boucle' => 'bucle',
'zbug_boucle_recursive_undef' => 'Bucle recurrent no definit: @nom@',
'zbug_calcul' => 'c&agrave;lcul',
'zbug_champ_hors_boucle' => 'Camp @champ@ fora de bucle',
'zbug_champ_hors_motif' => 'Camp @champ@ fora d\'un context @motif@',
'zbug_code' => 'codi',
'zbug_critere_inconnu' => 'Criteri desconegut @critere@',
'zbug_distant_interdit' => 'Prohibit amb dades externes',
'zbug_doublon_table_sans_cle_primaire' => 'Doublons en una taula sense clau prim&agrave;ria at&ograve;mica',
'zbug_doublon_table_sans_index' => 'Doublons em una taula sense &iacute;ndex',
'zbug_erreur_boucle_double' => 'Doble definici&oacute; del bucle @id@ ',
'zbug_erreur_boucle_fermant' => 'Bucle @id@ no tancat',
'zbug_erreur_boucle_syntaxe' => 'Sintaxi incorrecte del bucle @id@',
'zbug_erreur_compilation' => 'Error de compilaci&oacute;',
'zbug_erreur_execution_page' => 'Eerror d\'execuci&oacute;',
'zbug_erreur_filtre' => 'Filtre @filtre@ no definit',
'zbug_erreur_meme_parent' => 'El criteri {meme_parent} nom&eacute;s s\'aplica als bucles (FORUMS) o (RUBRIQUES)',
'zbug_erreur_squelette' => 'Error(s) en l\'esquelet',
'zbug_hors_compilation' => 'Sense Compilaci&oacute;',
'zbug_info_erreur_squelette' => 'Error en el lloc Web',
'zbug_inversion_ordre_inexistant' => 'Inversi&oacute; d\'un ordre inexistent',
'zbug_pagination_sans_critere' => 'Etiqueta #PAGINATION sense criteri {pagination} o  fet servir a dins d\'un bucle recursiu.',
'zbug_parametres_inclus_incorrects' => 'Par&agrave;metre d\'inclusi&oacute; incorrecte: @param@',
'zbug_profile' => 'Temps de c&agrave;lcul&nbsp;: @time@',
'zbug_resultat' => 'resultat',
'zbug_serveur_indefini' => 'Servidor SQL sense definir',
'zbug_statistiques' => 'Estad&iacute;stiques de peticions SQL classificades per durada',
'zbug_table_inconnue' => 'Taula SQL &laquo; @table@ &raquo; desconeguda',
'zxml_connus_attributs' => 'atributs conneguts',
'zxml_de' => 'de',
'zxml_inconnu_attribut' => 'atribut desconegut',
'zxml_inconnu_balise' => 'etiqueta desconeguda',
'zxml_inconnu_entite' => 'entitat desconeguda',
'zxml_inconnu_id' => 'ID desconegut',
'zxml_mais_de' => 'per&ograve; de',
'zxml_non_conforme' => 'no conforme al motiu',
'zxml_non_fils' => 'no &eacute;s un fill de',
'zxml_nonvide_balise' => 'etiqueta no buida',
'zxml_obligatoire_attribut' => 'atribut obligatori per&ograve; absent a dins de',
'zxml_succession_fils_incorrecte' => 'her&egrave;ncia de fills incorrecte',
'zxml_survoler' => 'passar el ratol&iacute; per sobre per veure els correctes',
'zxml_valeur_attribut' => 'valor de l\'atribut',
'zxml_vide_balise' => 'etiqueta buida',
'zxml_vu' => 'vist abans'
);

?>
